@@ -36,13 +36,13 @@ class KWalletManager : public KXmlGuiWindow
 
 public:
     explicit KWalletManager(QWidget *parent = nullptr, const QString &name = QString(), Qt::WindowFlags f = 0);
-    virtual ~KWalletManager();
+    ~KWalletManager() override;
 
     void kwalletdLaunch();
     bool hasUnsavedChanges(const QString& name = QString()) const;
     bool canIgnoreUnsavedChanges();
 
-public slots:
+public Q_SLOTS:
     void createWallet();
     void deleteWallet();
     void closeWallet(const QString &walletName);
@@ -62,13 +62,12 @@ public Q_SLOTS: //dbus
     Q_SCRIPTABLE void updateWalletDisplay();
     Q_SCRIPTABLE void aWalletWasOpened();
 
-private slots:
+private Q_SLOTS:
     void shuttingDown();
     void possiblyQuit();
     void editorClosed(KXmlGuiWindow *e);
     void possiblyRescan(const QString &app, const QString &, const QString &);
     void setupWallet();
-    void openWallet();
     void closeAllWallets();
     void exportWallets();
     void importWallets();
